Listener

Struct Listener 

pub struct Listener { /* private fields */ }
EIS listener in a Unix socket.

Implementations

Source

impl Listener

pub fn bind(path: &Path) -> Result<Self>

Listens on a specific path.

Errors

Will return Err if binding to the given path or setting the socket to non-blocking mode fails.

pub fn bind_auto() -> Result<Self, BindError>

Listens on a file in XDG_RUNTIME_DIR.

Errors

Will return Err if a lock file cannot be locked, binding to the generated path fails or setting the socket to non-blocking mode fails.

pub fn path(&self) -> &Path

Get the path to the listener socket

pub fn accept(&self) -> Result<Option<Context>>

Accepts a connection from a client. Returns Ok(Some(_) if an incoming connection is ready, and Ok(None) if there is no connection ready (would block).

Errors

Will return Err if Context::new fails.