pub struct Pointer(/* private fields */);Expand description
Device sub-interface for relative pointer motion.
Server-side interface proxy for interface ei_pointer.
Interface for relative pointer motion requests and events.
This interface is only provided once per device and where a client requests ei_pointer.release the interface does not get re-initialized. An EIS implementation may adjust the behavior of the device (including removing the device) if the interface is released.
Implementations
Sourceimpl Pointer
impl Pointer
Sourcepub fn destroyed(&self, serial: u32)
pub fn destroyed(&self, serial: u32)
Pointer removal notification.
Note: This event is a destructor.
This object has been removed and a client should release all associated resources.
This object will be destroyed by the EIS implementation immediately after after this event is sent and as such the client must not attempt to use it after that point.
Parameters
serial: This event’s serial number.
Sourcepub fn motion_relative(&self, x: f32, y: f32)
pub fn motion_relative(&self, x: f32, y: f32)
Relative motion event.
Note: This event may only be used in a receiver context type.
See the ei_pointer.motion_relative request for details.
It is a protocol violation to send this request for a client of an ei_handshake.context_type other than receiver.
Parameters
xy